==> be_ixf_drupal-8.x-5.9.zip: be_ixf_drupal/CHANGELOG.md <==
# Changelog

## [Unreleased]

## [1.3.5] - 2025-03-12
### support
- Fixed Some Drupal security issues and Added null check for explode function

## [1.3.4] - 2024-12-03
### support
- Fixed Drupal community security review comments

## [1.3.3] - 2024-09-11
### support
- Added support for drupal 11 and added configurable protocol

## [1.3.2] - 2023-09-01
### support
- Added support for PHP 8.2 and fixed deprecated variables

## [1.3.1] - 2023-06-09
### support
- Added support for drupal10

## [1.3.0] - 2022-07-28
### support
- update core php BEIXFClient class

## [1.2.9] - 2022-06-30
### support
- update default direct api endpoint and add option to update canonical url

## [1.2.8] - 2021-11-09
### support
- Made module compatible for drupal9

## [1.2.7] - 2020-09-14
### Fix
- Added support for all pages including Node and custom pages

## [1.2.6] - 2020-09-08
### Fix
- Added vendor folder and php sdk to avoid composer install

## [1.2.5] - 2020-08-25
### Fix
- Node Revision view issue

## [1.2.4] - 2020-07-29
### Fix
- Node Revision issue

## [1.2.3] - 2020-07-27
### Fix
- sonarqube codesmell fix

## [1.2.2] - 2020-07-15
### Fix
- Coding Standard fix

## [1.2.1] - 2020-07-06
### Added
- Making Accound id as required

## [1.2.0] - 2020-06-23
### Fixed
- Removing Notices

## [1.0-rc2] - 2020-06-10
### Fixed
- Head String Fix to be in <head> region

## [1.0-beta12] - 2019-01-17
### Fixed
- Missed settings.xml file fix.  Changed default endpoint as well

## [1.0-beta11] - 2019-01-09
### Fixed
- Make settings match plugin name.  Please do not upgrade to this version
from prior to 1.0-beta10 without contacting support.
- If you do upgrade manually please goto Configuration->BrightEdge to
configure your org id, endpoint, and cache. The BrightEdge Foundation
- Content Blocks will remain in place.
- Changed the admin form to show new domain

## [1.0-beta10] - 2019-01-08
### Added
- Clarify autoload and addresses warnings

## [0.5.0] - 2018-02-28
### Added
- Fix up notices and warnings

## [0.4.1] - 2018-02-09
### Added
- Public beta 4 version with redirect node fix

## [0.3.1] - 2018-01-31
### Added
- Public beta 3 version with redirect node caching

==> be_ixf_drupal-8.x-5.10.zip: be_ixf_drupal/CHANGELOG.md <==
# Changelog

## [Unreleased]

## [1.3.7] - 2025-07-04
### support
- Added support for SCP 2.0 with storage capsule, also updates to the PHP SDK for same and removed LocalContentMethod.

## [1.3.6] - 2025-05-16
### support
- Fixed Norm URL protocol mismatch with module configurations.

## [1.3.5] - 2025-03-12
### support
- Fixed Some Drupal security issues and Added null check for explode function

## [1.3.4] - 2024-12-03
### support
- Fixed Drupal community security review comments

## [1.3.3] - 2024-09-11
### support
- Added support for drupal 11 and added configurable protocol

## [1.3.2] - 2023-09-01
### support
- Added support for PHP 8.2 and fixed deprecated variables

## [1.3.1] - 2023-06-09
### support
- Added support for drupal10

## [1.3.0] - 2022-07-28
### support
- update core php BEIXFClient class

## [1.2.9] - 2022-06-30
### support
- update default direct api endpoint and add option to update canonical url

## [1.2.8] - 2021-11-09
### support
- Made module compatible for drupal9

## [1.2.7] - 2020-09-14
### Fix
- Added support for all pages including Node and custom pages

## [1.2.6] - 2020-09-08
### Fix
- Added vendor folder and php sdk to avoid composer install

## [1.2.5] - 2020-08-25
### Fix
- Node Revision view issue

## [1.2.4] - 2020-07-29
### Fix
- Node Revision issue

## [1.2.3] - 2020-07-27
### Fix
- sonarqube codesmell fix

## [1.2.2] - 2020-07-15
### Fix
- Coding Standard fix

## [1.2.1] - 2020-07-06
### Added
- Making Accound id as required

## [1.2.0] - 2020-06-23
### Fixed
- Removing Notices

## [1.0-rc2] - 2020-06-10
### Fixed
- Head String Fix to be in <head> region

## [1.0-beta12] - 2019-01-17
### Fixed
- Missed settings.xml file fix.  Changed default endpoint as well

## [1.0-beta11] - 2019-01-09
### Fixed
- Make settings match plugin name.  Please do not upgrade to this version
from prior to 1.0-beta10 without contacting support.
- If you do upgrade manually please goto Configuration->BrightEdge to
configure your org id, endpoint, and cache. The BrightEdge Foundation
- Content Blocks will remain in place.
- Changed the admin form to show new domain

## [1.0-beta10] - 2019-01-08
### Added
- Clarify autoload and addresses warnings

## [0.5.0] - 2018-02-28
### Added
- Fix up notices and warnings

## [0.4.1] - 2018-02-09
### Added
- Public beta 4 version with redirect node fix

## [0.3.1] - 2018-01-31
### Added
- Public beta 3 version with redirect node caching
